@@ -1,4 +1,3 @@
-from __future__ import absolute_import, print_function
 import sys
 from fitz.fitz import *
 
@@ -30,91 +29,96 @@ import fitz.utils
 # Document
 # ------------------------------------------------------------------------------
 fitz.open = fitz.Document
-fitz.Document.getToC = fitz.utils.getToC
-fitz.Document.get_toc = fitz.utils.getToC
-fitz.Document.setToC = fitz.utils.setToC
-fitz.Document.set_toc = fitz.utils.setToC
-fitz.Document.set_toc_item = fitz.utils.setTOC_item
-fitz.Document.del_toc_item = fitz.utils.delTOC_item
 fitz.Document._do_links = fitz.utils.do_links
-fitz.Document.getPagePixmap = fitz.utils.getPagePixmap
-fitz.Document.get_page_pixmap = fitz.utils.getPagePixmap
-fitz.Document.getPageText = fitz.utils.getPageText
-fitz.Document.get_page_text = fitz.utils.getPageText
-fitz.Document.setMetadata = fitz.utils.setMetadata
-fitz.Document.set_metadata = fitz.utils.setMetadata
-fitz.Document.searchPageFor = fitz.utils.searchPageFor
-fitz.Document.search_page_for = fitz.utils.searchPageFor
-fitz.Document.newPage = fitz.utils.newPage
-fitz.Document.new_page = fitz.utils.newPage
-fitz.Document.insertPage = fitz.utils.insertPage
-fitz.Document.insert_page = fitz.utils.insertPage
-fitz.Document.getCharWidths = fitz.utils.getCharWidths
+fitz.Document.del_toc_item = fitz.utils.del_toc_item
 fitz.Document.get_char_widths = fitz.utils.getCharWidths
-fitz.Document.scrub = fitz.utils.scrub
-fitz.Document.set_ocmd = fitz.utils.set_ocmd
 fitz.Document.get_ocmd = fitz.utils.get_ocmd
+fitz.Document.get_page_pixmap = fitz.utils.getPagePixmap
+fitz.Document.get_page_text = fitz.utils.getPageText
+fitz.Document.get_toc = fitz.utils.getToC
+fitz.Document.getCharWidths = fitz.utils.getCharWidths
+fitz.Document.getPagePixmap = fitz.utils.getPagePixmap
+fitz.Document.getPageText = fitz.utils.getPageText
+fitz.Document.getToC = fitz.utils.getToC
+fitz.Document.insert_page = fitz.utils.insertPage
+fitz.Document.insertPage = fitz.utils.insertPage
+fitz.Document.new_page = fitz.utils.newPage
+fitz.Document.newPage = fitz.utils.newPage
+fitz.Document.scrub = fitz.utils.scrub
+fitz.Document.search_page_for = fitz.utils.searchPageFor
+fitz.Document.searchPageFor = fitz.utils.searchPageFor
+fitz.Document.set_metadata = fitz.utils.setMetadata
+fitz.Document.set_ocmd = fitz.utils.set_ocmd
+fitz.Document.set_toc = fitz.utils.setToC
+fitz.Document.set_toc_item = fitz.utils.set_toc_item
+fitz.Document.setMetadata = fitz.utils.setMetadata
+fitz.Document.setToC = fitz.utils.setToC
+fitz.Document.tobytes = fitz.Document.write
+fitz.Document.set_page_labels = fitz.utils.set_page_labels
+fitz.Document.get_page_numbers = fitz.utils.get_page_numbers
 
 # ------------------------------------------------------------------------------
 # Page
 # ------------------------------------------------------------------------------
 fitz.Page.apply_redactions = fitz.utils.apply_redactions
-fitz.Page.deleteWidget = fitz.utils.deleteWidget
 fitz.Page.delete_widget = fitz.utils.deleteWidget
-fitz.Page.drawBezier = fitz.utils.drawBezier
+fitz.Page.deleteWidget = fitz.utils.deleteWidget
 fitz.Page.draw_bezier = fitz.utils.drawBezier
-fitz.Page.drawCircle = fitz.utils.drawCircle
 fitz.Page.draw_circle = fitz.utils.drawCircle
-fitz.Page.drawCurve = fitz.utils.drawCurve
 fitz.Page.draw_curve = fitz.utils.drawCurve
-fitz.Page.drawLine = fitz.utils.drawLine
 fitz.Page.draw_line = fitz.utils.drawLine
-fitz.Page.drawOval = fitz.utils.drawOval
 fitz.Page.draw_oval = fitz.utils.drawOval
-fitz.Page.drawPolyline = fitz.utils.drawPolyline
 fitz.Page.draw_polyline = fitz.utils.drawPolyline
-fitz.Page.drawQuad = fitz.utils.drawQuad
 fitz.Page.draw_quad = fitz.utils.drawQuad
-fitz.Page.drawRect = fitz.utils.drawRect
 fitz.Page.draw_rect = fitz.utils.drawRect
-fitz.Page.drawSector = fitz.utils.drawSector
 fitz.Page.draw_sector = fitz.utils.drawSector
-fitz.Page.drawSquiggle = fitz.utils.drawSquiggle
 fitz.Page.draw_squiggle = fitz.utils.drawSquiggle
-fitz.Page.drawZigzag = fitz.utils.drawZigzag
 fitz.Page.draw_zigzag = fitz.utils.drawZigzag
-fitz.Page.getLinks = fitz.utils.getLinks
+fitz.Page.drawBezier = fitz.utils.drawBezier
+fitz.Page.drawCircle = fitz.utils.drawCircle
+fitz.Page.drawCurve = fitz.utils.drawCurve
+fitz.Page.drawLine = fitz.utils.drawLine
+fitz.Page.drawOval = fitz.utils.drawOval
+fitz.Page.drawPolyline = fitz.utils.drawPolyline
+fitz.Page.drawQuad = fitz.utils.drawQuad
+fitz.Page.drawRect = fitz.utils.drawRect
+fitz.Page.drawSector = fitz.utils.drawSector
+fitz.Page.drawSquiggle = fitz.utils.drawSquiggle
+fitz.Page.drawZigzag = fitz.utils.drawZigzag
 fitz.Page.get_links = fitz.utils.getLinks
-fitz.Page.getPixmap = fitz.utils.getPixmap
 fitz.Page.get_pixmap = fitz.utils.getPixmap
-fitz.Page.getText = fitz.utils.getText
 fitz.Page.get_text = fitz.utils.getText
-fitz.Page.getTextbox = fitz.utils.getTextbox
-fitz.Page.get_textbox = fitz.utils.getTextbox
-fitz.Page.getTextSelection = fitz.utils.getTextSelection
-fitz.Page.get_text_selection = fitz.utils.getTextSelection
-fitz.Page.getTextBlocks = fitz.utils.getTextBlocks
 fitz.Page.get_text_blocks = fitz.utils.getTextBlocks
-fitz.Page.getTextWords = fitz.utils.getTextWords
+fitz.Page.get_text_selection = fitz.utils.getTextSelection
 fitz.Page.get_text_words = fitz.utils.getTextWords
-fitz.Page.insertImage = fitz.utils.insertImage
+fitz.Page.get_textbox = fitz.utils.getTextbox
+fitz.Page.getLinks = fitz.utils.getLinks
+fitz.Page.getPixmap = fitz.utils.getPixmap
+fitz.Page.getText = fitz.utils.getText
+fitz.Page.getTextBlocks = fitz.utils.getTextBlocks
+fitz.Page.getTextbox = fitz.utils.getTextbox
+fitz.Page.getTextSelection = fitz.utils.getTextSelection
+fitz.Page.getTextWords = fitz.utils.getTextWords
 fitz.Page.insert_image = fitz.utils.insertImage
-fitz.Page.insertLink = fitz.utils.insertLink
 fitz.Page.insert_link = fitz.utils.insertLink
-fitz.Page.insertText = fitz.utils.insertText
 fitz.Page.insert_text = fitz.utils.insertText
-fitz.Page.insertTextbox = fitz.utils.insertTextbox
 fitz.Page.insert_textbox = fitz.utils.insertTextbox
-fitz.Page.newShape = lambda x: fitz.utils.Shape(x)
+fitz.Page.insertImage = fitz.utils.insertImage
+fitz.Page.insertLink = fitz.utils.insertLink
+fitz.Page.insertText = fitz.utils.insertText
+fitz.Page.insertTextbox = fitz.utils.insertTextbox
 fitz.Page.new_shape = lambda x: fitz.utils.Shape(x)
-fitz.Page.searchFor = fitz.utils.searchFor
+fitz.Page.newShape = lambda x: fitz.utils.Shape(x)
 fitz.Page.search = fitz.utils.searchFor
-fitz.Page.showPDFpage = fitz.utils.showPDFpage
+fitz.Page.searchFor = fitz.utils.searchFor
 fitz.Page.show_pdf_page = fitz.utils.showPDFpage
+fitz.Page.showPDFpage = fitz.utils.showPDFpage
 fitz.Page.updateLink = fitz.utils.updateLink
 fitz.Page.updte_link = fitz.utils.updateLink
-fitz.Page.writeText = fitz.utils.writeText
 fitz.Page.write_text = fitz.utils.writeText
+fitz.Page.writeText = fitz.utils.writeText
+fitz.Page.get_label = fitz.utils.get_label
+
 # ------------------------------------------------------------------------------
 # Annot
 # ------------------------------------------------------------------------------
